
#include "ibtmex.h"

// structre to hold the DS2480/COM default values
typedef struct
{
   uchar PDSRC;      // pull-down slew rate control
   uchar W1LT;       // 1-wire low time
   uchar DSOWORT;    // data sample offset and write 0 recovery time
   uchar SearchBaud; // streaming search baud rate 
   uchar BitBaud;    // streaming bit baud rate
   uchar ByteBaud;   // streaming byte baud rate
  
} UDefaultType;

// structure used in TMLine API to 
typedef struct
{
   char ID[7];                      // ID string "DS2480"
   uchar Operation;                 // Read (1) or Set (0)
   UDefaultType NormalDefault;      // default values for Regular speed
   UDefaultType OverDriveDefault;   // default values for Overdrive speed
   UDefaultType RelaxedDefault;     // default values for Flex speed
   uchar MXBAUD;                    // overall max baud rate
   short MAXSEND;                   // max bytes to send at one time
   short MINSEND;                   // min bytes to send at one time
} LineType;


extern "C" short far pascal TMLine(long, LineType far *);

#define READ_FUNCTION           1
#define WRITE_FUNCTION          0

// Pull down slew rate.
#define PARMSET_Slew15Vus              0x00
#define PARMSET_Slew2p2Vus             0x02
#define PARMSET_Slew1p65Vus            0x04
#define PARMSET_Slew1p37Vus            0x06
#define PARMSET_Slew1p1Vus             0x08
#define PARMSET_Slew0p83Vus            0x0A
#define PARMSET_Slew0p7Vus             0x0C
#define PARMSET_Slew0p55Vus            0x0E

// Write 1 low time
#define PARMSET_Write8us               0x00
#define PARMSET_Write9us               0x02
#define PARMSET_Write10us              0x04
#define PARMSET_Write11us              0x06
#define PARMSET_Write12us              0x08
#define PARMSET_Write13us              0x0A
#define PARMSET_Write14us              0x0C
#define PARMSET_Write15us              0x0E

// Data sample offset and Write 0 recovery time (3.10)
#define PARMSET_SampOff3us             0x00
#define PARMSET_SampOff4us             0x02
#define PARMSET_SampOff5us             0x04
#define PARMSET_SampOff6us             0x06
#define PARMSET_SampOff7us             0x08
#define PARMSET_SampOff8us             0x0A
#define PARMSET_SampOff9us             0x0C
#define PARMSET_SampOff10us            0x0E

// Baud rate bits
#define PARMSET_9600                   0x00
#define PARMSET_19200                  0x02
#define PARMSET_57600                  0x04
#define PARMSET_115200                 0x06

